// -*-Mode: C++;-*-
/*
 * $Id: TextInput.h,v 2.1 1999/03/09 01:03:59 ral Exp $;
 * Header file for CTextInput
 */
#ifndef CTextInput_included
#define CTextInput_included

#include "TextInputData.h"

class CTextInput : public CTextInputData
{
    Q_OBJECT
public:
    CTextInput (QWidget* parent = NULL,const char* name = NULL);
    virtual ~CTextInput();
    const char*get_text(){return InputField->text();}

protected slots:
    void accept_field();
    void inputChanged(const char*);

};
#endif // CTextInput_included
